%{?mingw_package_header}

%global pkgname libzip

Name:           mingw-%{pkgname}
Version:        1.1.1
Release:        1%{?dist}
Summary:        C library for reading, creating, and modifying zip archives

License:        BSD
BuildArch:      noarch
URL:            http://www.nih.at/libzip/index.html
Source0:        http://www.nih.at/libzip/%{pkgname}-%{version}.tar.xz

# Fix cmake soversion not in sync with automake one, and install pkgconfig file
Patch0:         libzip_cmake-fixes.patch
# fix undefined optopt
Patch1:         libzip-build.patch

BuildRequires:  cmake

BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-binutils
BuildRequires:  mingw32-zlib >= 1.1.2

BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-binutils
BuildRequires:  mingw64-zlib >= 1.1.2


%description
libzip is a C library for reading, creating, and modifying zip archives. Files
can be added from data buffers, files, or compressed data copied directly from 
other zip archives. Changes made without closing the archive can be reverted. 
The API is documented by man pages.


%package -n mingw32-%{pkgname}
Summary:        C library for reading, creating, and modifying zip archives

%description -n mingw32-%{pkgname}
libzip is a C library for reading, creating, and modifying zip archives. Files
can be added from data buffers, files, or compressed data copied directly from
other zip archives. Changes made without closing the archive can be reverted.
The API is documented by man pages.


%package -n mingw64-%{pkgname}
Summary:        C library for reading, creating, and modifying zip archives

%description -n mingw64-%{pkgname}
libzip is a C library for reading, creating, and modifying zip archives. Files
can be added from data buffers, files, or compressed data copied directly from
other zip archives. Changes made without closing the archive can be reverted.
The API is documented by man pages.


%{?mingw_debug_package}


%prep
%setup -q -n %{pkgname}-%{version}
%patch0 -p1
%patch1 -p1


%build
%mingw_cmake
%mingw_make %{?_smp_mflags}


%install
%mingw_make install DESTDIR=%{buildroot}

# Fix rhbz#1008128
ln -s %{mingw32_libdir}/libzip/include/zipconf.h %{buildroot}%{mingw32_includedir}/zipconf.h
ln -s %{mingw64_libdir}/libzip/include/zipconf.h %{buildroot}%{mingw64_includedir}/zipconf.h

# Remove files we don't need
rm -r %{buildroot}%{mingw32_datadir}/*
rm -r %{buildroot}%{mingw64_datadir}/*

# Install and adjust pkg-config files
install -Dpm 0644 libzip.pc.in %{buildroot}%{mingw32_libdir}/pkgconfig/libzip.pc
sed -i -e 's|@prefix@|%{mingw32_prefix}|g' \
       -e 's|@exec_prefix@|%{mingw32_prefix}|g' \
       -e 's|@libdir@|%{mingw32_libdir}|g' \
       -e 's|@includedir@|%{mingw32_includedir}|g' \
       -e 's|@PACKAGE@|%{pkgname}|g' \
       -e 's|@VERSION@|%{version}|g' \
       -e 's|@PKG_CONFIG_RPATH@||g' \
       -e 's|@LIBS@||g' %{buildroot}%{mingw32_libdir}/pkgconfig/libzip.pc

install -Dpm 0644 libzip.pc.in %{buildroot}%{mingw64_libdir}/pkgconfig/libzip.pc
sed -i -e 's|@prefix@|%{mingw64_prefix}|g' \
       -e 's|@exec_prefix@|%{mingw64_prefix}|g' \
       -e 's|@libdir@|%{mingw64_libdir}|g' \
       -e 's|@includedir@|%{mingw64_includedir}|g' \
       -e 's|@PACKAGE@|%{pkgname}|g' \
       -e 's|@VERSION@|%{version}|g' \
       -e 's|@PKG_CONFIG_RPATH@||g' \
       -e 's|@LIBS@||g' %{buildroot}%{mingw64_libdir}/pkgconfig/libzip.pc


%files -n mingw32-%{pkgname}
%doc AUTHORS NEWS README THANKS TODO
%license LICENSE
%{mingw32_bindir}/zipcmp.exe
%{mingw32_bindir}/zipmerge.exe
%{mingw32_bindir}/ziptool.exe
%{mingw32_bindir}/libzip-4.dll
%{mingw32_libdir}/libzip.dll.a
%{mingw32_libdir}/pkgconfig/libzip.pc
%{mingw32_libdir}/libzip/
%{mingw32_includedir}/zip.h
%{mingw32_includedir}/zipconf.h

%files -n mingw64-%{pkgname}
%doc AUTHORS NEWS README THANKS TODO
%license LICENSE
%{mingw64_bindir}/zipcmp.exe
%{mingw64_bindir}/zipmerge.exe
%{mingw64_bindir}/ziptool.exe
%{mingw64_bindir}/libzip-4.dll
%{mingw64_libdir}/libzip.dll.a
%{mingw64_libdir}/pkgconfig/libzip.pc
%{mingw64_libdir}/libzip/
%{mingw64_includedir}/zip.h
%{mingw64_includedir}/zipconf.h


%changelog
* Sat Feb 13 2016 Sandro Mani <manisandro@gmail.com> - 1.1.1-1
- Update to 1.1.1
- Fix pkg-config files

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jan 29 2016 Sandro Mani <manisandro@gmail.com> - 1.1-1
- Update to 1.1

* Mon Nov 09 2015 Sandro Mani <manisandro@gmail.com> - 1.0.1-3
- Build with cmake to include win32 specific API (#1279580)

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed May 06 2015 Sandro Mani <manisandro@gmail.com> - 1.0.1-1
- Update to 1.0.1

* Mon Mar 23 2015 Sandro Mani <manisandro@gmail.com> - 0.11.2-3
- CVE-2015-2331: integer overflow when processing ZIP archives (#1204676,#1204677)

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.11.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Dec 19 2013 Sandro Mani <manisandro@gmail.com> - 0.11.2-1
- Update to 0.11.2

* Tue Sep 17 2013 Sandro Mani <manisandro@gmail.com> - 0.11.1-3
- Link zipconf.h to include dir (fix rhbz#1008128)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.11.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Jun 16 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 0.11.1-1
- Update to 0.11.1
- Use a more verbose filelist

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Dec 03 2012 Alexandru Gagniuc <mr.nuke.me@gmail.com> - 0.9-8
- Added target for mingw64

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Mar 07 2012 Kalev Lember <kalevlember@gmail.com> - 0.9-6
- Renamed the source package to mingw-libzip (#800932)
- Modernize the spec file
- Use mingw macros without leading underscore

* Mon Feb 27 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 0.9-5
- Rebuild against the mingw-w64 toolchain

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Dec 22 2009 David Ludlow <dave@adsllc.com> - 0.9-2
- Prevent owning a directory that is not mine to own

* Tue Dec 22 2009 David Ludlow <dave@adsllc.com> - 0.9-1
- Initial creation of mingw32 package
